.. _main_page:

#############################################
Operator Discretization Library Documentation
#############################################

Operator Discretization Library (ODL) is a python library for fast prototyping focusing on (but not restricted to) inverse problems.

The main intent of ODL is to enable mathematicians and applied scientists to use different numerical methods on real-world problems without having to implement all necessary parts from the bottom up. ODL provides some of the most heavily used building blocks for numerical algorithms out of the box, which enables users to focus on real scientific issues.


.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    getting_started/getting_started


.. toctree::
    :maxdepth: 2
    :caption: Working with ODL

    guide/guide
    math/math

.. toctree::
    :maxdepth: 2
    :caption: Developer zone

    dev/dev

.. toctree::
    :maxdepth: 1
    :caption: Useful facts

    guide/faq
    guide/glossary
    release_notes

.. toctree::
    :hidden:

    refs

.. toctree::
    :maxdepth: 2
    :caption: API Reference

    odl


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

